# turnstone console

NODES
Loading cluster data...
WORKSTREAMS
STATE NAME MODEL NODE TASK TOKENS CTX
Open node UI
WORKSTREAMS
STATE NAME MODEL NODE TASK TOKENS CTX
USERS
USERNAME DISPLAY NAME CREATED ACTIONS
Loading users...
TOKENS Filter tokens by user
PREFIX NAME SCOPES CREATED EXPIRES ACTIONS
Select a user to view tokens
CHANNEL LINKS Filter channels by user
CHANNEL EXTERNAL ID LINKED ACTIONS
Select a user to view channel links
SCHEDULED TASKS
NAME TYPE SCHEDULE TARGET NEXT RUN STATUS ACTIONS
Loading schedules...
WATCHES Filter watches by node
NAME NODE COMMAND INTERVAL POLL CONDITION STATUS ACTIONS
Loading watches...
ROLES
NAME PERMISSIONS ACTIONS
Loading roles...
TOOL POLICIES
NAME PATTERN ACTION PRI STATUS ACTIONS
Loading policies...
PROMPT TEMPLATES
NAME CATEGORY VARIABLES ACTIONS
Loading templates...
USAGE
Loading usage data...
AUDIT LOG Filter by action
Filter by user
TIME USER ACTION RESOURCE DETAIL
Loading audit log...
Loading...

## New Workstream

Node
Name optional Model optional Template optional
Task optional — sent as first message

## Create User

Username Display name Password Confirm password

## Create API Token

Token name optional Scopes
Expiry optional

## Token Created

Copy this token now. It will not be shown again.

## Confirm

## Link Channel Account

Channel type
External user ID the user's ID on the platform

## New Schedule

Name Description optional Schedule type
Cron expression min hour day month weekday
Run at
Target
Node ID
Model optional Template optional Initial message Auto-approve tool calls

## Edit Schedule

Name Description Schedule type
Cron expression
Run at
Target
Node ID
Model Template optional Initial message Auto-approve tool calls Enabled

## Run History

## Create Role

Name Display name
Permissions

## Edit Role

Display name
Permissions

## Assign Roles

## Create Tool Policy

Name Tool pattern glob syntax: bash*, file_write, * Action
Priority higher = evaluated first

## Edit Tool Policy

Name Tool pattern Action
Priority Enabled

## Create Prompt Template

Name Category
Content system message text, use {{model}}, {{ws_id}}, {{node_id}} for placeholders Variables auto-detected from content — available: model, ws_id, node_id
Set as default for new workstreams

## Edit Prompt Template

Name Category
Content Variables auto-detected from content — available: model, ws_id, node_id
Set as default